@@ -3,6 +3,7 @@
 #' @import utils
 
 setOldClass("lfactor")
-setGeneric("match")
-setGeneric("%in%")
+#setGeneric("match")
+#setGeneric("%in%")
+#setGeneric("as.factor")
 
